==> blackfin.2.2.0.euc.tar.gz: blackfin/ezkit_bf533/board_config.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  TOPPERS/JSP for Blackfin
 *
 *  Copyright (C) 2004,2006,2006 by Takemasa Nakamura
 *  Copyright (C) 2004 by Ujinosuke
 *
 *  嵭Ԥϡʲ (1)(4) ξ狼Free Software Foundation 
 *  ˤäƸɽƤ GNU General Public License  Version 2 ˵
 *  ҤƤ˸¤ꡤܥեȥܥեȥ
 *  ѤΤޤࡥʲƱˤѡʣѡۡʰʲ
 *  ѤȸƤ֡ˤ뤳Ȥ̵ǵ롥
 *  (1) ܥեȥ򥽡ɤηѤˤϡ嵭
 *      ɽѾ浪Ӳ̵ݾڵ꤬Τޤޤηǥ
 *      ˴ޤޤƤ뤳ȡ
 *  (2) ܥեȥ򡤥饤֥ʤɡ¾Υեȥȯ˻
 *      ѤǤǺۤˤϡۤȼɥȡ
 *      ԥޥ˥奢ʤɡˤˡ嵭ɽѾ浪Ӳ
 *      ̵ݾڵǺܤ뤳ȡ
 *  (3) ܥեȥ򡤵Ȥ߹ʤɡ¾Υեȥȯ˻
 *      ѤǤʤǺۤˤϡΤ줫ξ
 *      ȡ
 *    (a) ۤȼɥȡѼԥޥ˥奢ʤɡˤˡ嵭
 *        ɽѾ浪Ӳ̵ݾڵǺܤ뤳ȡ
 *    (b) ۤη֤̤ˡˤäơTOPPERSץȤ
 *        𤹤뤳ȡ
 *  (4) ܥեȥѤˤľŪޤϴŪ뤤ʤ»
 *      ⡤嵭ԤTOPPERSץȤդ뤳ȡ
 * 
 *  ܥեȥϡ̵ݾڤ󶡤ƤΤǤ롥嵭Ԥ
 *  TOPPERSץȤϡܥեȥ˴ؤơŬѲǽ
 *  ޤơʤݾڤԤʤޤܥեȥѤˤľ
 *  ŪޤϴŪʤ»˴ؤƤ⡤Ǥʤ
 * 
 *  
 */
 
 
 
#ifndef _BOARD_CONFIG_H_
#define _BOARD_CONFIG_H_

/*
 * ADSP-BF533˰¸ܡɤؤμˤäƷޤѥ᡼
 * 롣
 */


/*
 * ɤΤ褦ʥåϤˤбǤ褦ʲCSEL, SSEL, MSEL
 * ȥåϼȿ(Hz)ꤹ롣PLLΥץsys_config.c
 * sys_initialize()ؿǹԤ롣
 *
 * CSELVAL1,2,4,8椫֡CLKINñ̤Hz
 */
 
#define CSELVAL 1
#define SSELVAL 5
#define MSELVAL 22
#define CLKIN 27000000

/*
 * TICѥޡ
 * USE_TIC_COREdefineȡCOREޡѤ
 * ȥȤȡGP_TIMER_2Ѥ
 *
 * COREޡwakeupʤᡢǥѥå
 * idle̿ȤäCOREޡ٥ȤԤĤȤǤʤ
 * ΤᡢUSE_TIC_COREȤȥǥѥåidle̿
 * Ȥ鷺˳ȯݡ󥰤ԤġϾϤ
 * Ǥ롣
 *
 */
//#define USE_TIC_CORE

/*
 * ϡɥ顼ߤε
 * USE_HW_ERRORdefineȡINHNO_HW_ERRORȤ褦
 * ʤ롣ˤΥϥɥϿȼ¹Ԥߤ롣
 *
 */
//#define USE_HW_ERROR


/*
 * ¹Իؿλ
 * 
 * ޥ USE_RUNTIME_INIT ȡstart.asmΤʤ _mi_initialize
 * ƤӽФδؿϥΡ֡ȥ⡼ɤǵưȤˤΤɬפˤʤΤ
 * ̾ USE_RUNTIME_INITȤɬפϤʤ
 * ܺ٤ADIEE239˾ܤhttp://tinyurl.com/2hpbk (tinyURL)
 * 
*/
//#define USE_RUNTIME_INIT

/*
 * ͥߤ
 * 
 * ޥUNMANAGED_INTϥͥߤ롣
 * ޥ16ӥåȤΥӥåȥޥåפˤʤäƤꡢʲˤѥ
 * ΤҤȤĤȤʤɤΤ褦ʥѥǤNMIϴ
 * ߤȤư롣
 * UNMANAGED_INTʤ硢NMIߤȤư롣
 * 
*/
//#define UNMANAGED_INT 0x0020			// IVHWͥ.
//#define UNMANAGED_INT 0x0060			// IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x00E0			// IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x01E0			// IVG8 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x03E0			// IVG9 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x07E0			// IVG10 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x0FE0			// IVG11 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x1FE0			// IVG12 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x3FE0			// IVG13 ... IVG7, IVTMRIVHWͥ.

/*
 * C++Ϣ񸻤Ѱդ
 * 
 * ޥINIT_C_PLUS_PLUSȡC++ѤΥơ֥
 * ɤ¹Ԥ롣ޤC++ѤΥơ֥
 * 
*/
#define INIT_C_PLUS_PLUS

/*
 *  ưåΥåȥƥ̾
 */
#define	TARGET_NAME	"EZ-KIT Lite BF533"


/*
 *  ꥢݡȿ
 *  TNUM_SIOP_XXXϡUARTμ̤Ȥ롣
 *  TNUM_SIOP_UARTBF533¢UARTΤPDICѤΡ
 *  BF533UARTҤȤĤäƤʤΤǡ10롣
 *  TNUM_PORTϡTNUM_SIOP_XXXΤGDICѤΤ¡
 *  uart.cǻȤ
 */
#define TNUM_PORT	1		/* GDICݡȤ륷ꥢݡȤο */
#define TNUM_SIOP_UART	1	/* PIDCݡȤ륷ꥢݡȤο */

/*
 *  ꥢݡֹ˴ؤ
 *  ꥢݡȤȤʤ̵뤷Ƥ
 */
#define	LOGTASK_PORTID	1	/* ƥѤ륷ꥢݡֹ */

#ifndef __SILICON_REVISION__
#define __SILICON_REVISION__ 0x02
#endif

#endif // _BOARD_CONFIG_H_

==> blackfin.2.3.0.euc.tar.gz: blackfin/ezkit_bf533/board_config.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  TOPPERS/JSP for Blackfin
 *
 *  Copyright (C) 2004,2006,2006 by Takemasa Nakamura
 *  Copyright (C) 2004 by Ujinosuke
 *
 *  嵭Ԥϡʲ (1)(4) ξ狼Free Software Foundation 
 *  ˤäƸɽƤ GNU General Public License  Version 2 ˵
 *  ҤƤ˸¤ꡤܥեȥܥեȥ
 *  ѤΤޤࡥʲƱˤѡʣѡۡʰʲ
 *  ѤȸƤ֡ˤ뤳Ȥ̵ǵ롥
 *  (1) ܥեȥ򥽡ɤηѤˤϡ嵭
 *      ɽѾ浪Ӳ̵ݾڵ꤬Τޤޤηǥ
 *      ˴ޤޤƤ뤳ȡ
 *  (2) ܥեȥ򡤥饤֥ʤɡ¾Υեȥȯ˻
 *      ѤǤǺۤˤϡۤȼɥȡ
 *      ԥޥ˥奢ʤɡˤˡ嵭ɽѾ浪Ӳ
 *      ̵ݾڵǺܤ뤳ȡ
 *  (3) ܥեȥ򡤵Ȥ߹ʤɡ¾Υեȥȯ˻
 *      ѤǤʤǺۤˤϡΤ줫ξ
 *      ȡ
 *    (a) ۤȼɥȡѼԥޥ˥奢ʤɡˤˡ嵭
 *        ɽѾ浪Ӳ̵ݾڵǺܤ뤳ȡ
 *    (b) ۤη֤̤ˡˤäơTOPPERSץȤ
 *        𤹤뤳ȡ
 *  (4) ܥեȥѤˤľŪޤϴŪ뤤ʤ»
 *      ⡤嵭ԤTOPPERSץȤդ뤳ȡ
 * 
 *  ܥեȥϡ̵ݾڤ󶡤ƤΤǤ롥嵭Ԥ
 *  TOPPERSץȤϡܥեȥ˴ؤơŬѲǽ
 *  ޤơʤݾڤԤʤޤܥեȥѤˤľ
 *  ŪޤϴŪʤ»˴ؤƤ⡤Ǥʤ
 * 
 *  
 */
 
 
 
#ifndef _BOARD_CONFIG_H_
#define _BOARD_CONFIG_H_

/*
 * ADSP-BF533˰¸ܡɤؤμˤäƷޤѥ᡼
 * 롣
 */


/*
 * ɤΤ褦ʥåϤˤбǤ褦ʲCSEL, SSEL, MSEL
 * ȥåϼȿ(Hz)ꤹ롣PLLΥץsys_config.c
 * sys_initialize()ؿǹԤ롣
 *
 * CSELVAL1,2,4,8椫֡CLKINñ̤Hz
 */
 
#define CSELVAL 1
#define SSELVAL 5
#define MSELVAL 22
#define CLKIN 27000000

/*
 * TICѥޡ
 * USE_TIC_COREdefineȡCOREޡѤ
 * ȥȤȡGP_TIMER_2Ѥ
 *
 * COREޡwakeupʤᡢǥѥå
 * idle̿ȤäCOREޡ٥ȤԤĤȤǤʤ
 * ΤᡢUSE_TIC_COREȤȥǥѥåidle̿
 * Ȥ鷺˳ȯݡ󥰤ԤġϾϤ
 * Ǥ롣
 *
 */
//#define USE_TIC_CORE

/*
 * ϡɥ顼ߤε
 * QUICK_HW_ERRORdefineȡϡɥ顼٥
 * ¨¤˼롣defineʤˤϡԤ֤
 * ϡɥ顼ߤȯ硢γߤޤ
 * Ԥ뤳Ȥˤʤ롣
 *
 */
//#define QUICK_HW_ERROR


/*
 * ¹Իؿλ
 * 
 * ޥ USE_RUNTIME_INIT ȡstart.asmΤʤ _mi_initialize
 * ƤӽФδؿϥΡ֡ȥ⡼ɤǵưȤˤΤɬפˤʤΤ
 * ̾ USE_RUNTIME_INITȤɬפϤʤ
 * ܺ٤ADIEE239˾ܤhttp://tinyurl.com/2hpbk (tinyURL)
 * 
*/
//#define USE_RUNTIME_INIT

/*
 * ͥߤ
 * 
 * ޥUNMANAGED_INTϥͥߤ롣
 * ޥ16ӥåȤΥӥåȥޥåפˤʤäƤꡢʲˤѥ
 * ΤҤȤĤȤʤɤΤ褦ʥѥǤNMIϴ
 * ߤȤư롣
 * UNMANAGED_INTʤ硢NMIߤȤư롣
 * 
*/
//#define UNMANAGED_INT 0x0020			// IVHWͥ.
//#define UNMANAGED_INT 0x0060			// IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x00E0			// IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x01E0			// IVG8 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x03E0			// IVG9 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x07E0			// IVG10 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x0FE0			// IVG11 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x1FE0			// IVG12 ... IVG7, IVTMRIVHWͥ.
//#define UNMANAGED_INT 0x3FE0			// IVG13 ... IVG7, IVTMRIVHWͥ.

/*
 * C++Ϣ񸻤Ѱդ
 * 
 * ޥINIT_C_PLUS_PLUSȡC++ѤΥơ֥
 * ɤ¹Ԥ롣ޤC++ѤΥơ֥
 * 
*/
#define INIT_C_PLUS_PLUS

/*
 *  ưåΥåȥƥ̾
 */
#define	TARGET_NAME	"EZ-KIT Lite BF533"


/*
 *  ꥢݡȿ
 *  TNUM_SIOP_XXXϡUARTμ̤Ȥ롣
 *  TNUM_SIOP_UARTBF533¢UARTΤPDICѤΡ
 *  BF533UARTҤȤĤäƤʤΤǡ10롣
 *  TNUM_PORTϡTNUM_SIOP_XXXΤGDICѤΤ¡
 *  uart.cǻȤ
 */
#define TNUM_PORT	1		/* GDICݡȤ륷ꥢݡȤο */
#define TNUM_SIOP_UART	1	/* PIDCݡȤ륷ꥢݡȤο */

/*
 *  ꥢݡֹ˴ؤ
 *  ꥢݡȤȤʤ̵뤷Ƥ
 */
#define	LOGTASK_PORTID	1	/* ƥѤ륷ꥢݡֹ */

#ifndef __SILICON_REVISION__
#define __SILICON_REVISION__ 0x02
#endif

#endif // _BOARD_CONFIG_H_
